Clojure only.

teensyp.concurrent

Utility functions and macros for concurrent programming.

Utility functions and macros for concurrent programming.
raw docstring

with-lockcljmacro

(with-lock lock & body)

Lock the supplied lock before running the body, and finally unlock the lock once the body is complete or has thrown an exception.

Lock the supplied lock before running the body, and finally unlock
the lock once the body is complete or has thrown an exception.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries