Utility functions and macros for concurrent programming.
Utility functions and macros for concurrent programming.
(with-lock lock & body)Lock the supplied lock before running the body, and finally unlock the lock once the body is complete or has thrown an exception.
Lock the supplied lock before running the body, and finally unlock the lock once the body is complete or has thrown an exception.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |